/******************************************************************************
 * Functions for position system:
 *****************************************************************************/

#include "iar.h"
#include "coordinate.h"
#include "my_stdio.h"
#include "encoders.h"

int com_getraw(int fd_out, char * name)
{
	fd_printf(fd_out,"%5d %5d\n", 
		  get_encoder(0), get_encoder(1) );

	return 0;
}

int com_set_zero(int fd_out, char * name)
{
	char *cm;

	cm = stripwhite(name);
	switch( str2cord_type(cm) ){
	case DEC_CASE:
		fd_printf(fd_out,"# set declination encoder to 0.\n");
		return encoder_set_zero(encoder_num[DEC_CASE]);
	case RA_CASE:
		fd_printf(fd_out,"# set right accession encoder to 0.\n");
		return encoder_set_zero(encoder_num[RA_CASE]);
	default:
		fd_printf(fd_out,"# set zero: argument error: %s\n", cm);
		return -1;
	}
}


int com_set_cw(int fd_out, char * name)
{
	char *cm;

	cm = stripwhite(name);
	switch( str2cord_type(cm) ){
	case DEC_CASE:
		fd_printf(fd_out,
			  "# set dec. encoder to clockwhise increment.\n");
		return encoder_set_cw(encoder_num[DEC_CASE]);
	case RA_CASE:
		fd_printf(fd_out,
			  "# set ra encoder to clockwhise increment.\n");
		return encoder_set_cw(encoder_num[RA_CASE]);
	default:
		fd_printf(fd_out,"# set cw: argument error: %s\n", cm);
		return -1;
	}
}


int com_set_ccw(int fd_out, char * name)
{
	char *cm;

	cm = stripwhite(name);
	switch( str2cord_type(cm) ){
	case DEC_CASE:
		fd_printf(fd_out,
			  "# set dec. encoder to counter clockwhise increment.\n");
		return encoder_set_ccw(encoder_num[DEC_CASE]);
	case RA_CASE:
		fd_printf(fd_out,
			  "# set ra encoder to counter clockwhise increment.\n");
		return encoder_set_ccw(encoder_num[RA_CASE]);
	default:
		fd_printf(fd_out,"# set ccw: argument error: %s\n", cm);
		return -1;
	}
}


int com_test_sclk(int fd_out, char * name)
{
	int res;

	if ( (res = sidereal_clock_running()) ) {
		fd_printf(fd_out,"# Sidereal Clock running.\n");
		fd_printf(fd_out,"r: 1\n");
	}
	else {
		fd_printf(fd_out,"# Sidereal NOT Clock running.\n");
		fd_printf(fd_out,"r: 0\n");
	}
	
	return res;

}


int com_put_fail_clk(int fd_out, char * name)
{
	int res;

	switch ( (res = put_on_fail_condition()) ){
	case 1:
		fd_printf(fd_out,"# Is current condition\n");
		fd_printf(fd_out,"r: 2\n");
		break;
	case 0:
		fd_printf(fd_out,"# Now in fail condition\n");
		fd_printf(fd_out,"r: 1\n");
		break;
	default:
		fd_printf(fd_out,"# ERROR: continuing in normal condition\n");
		fd_printf(fd_out,"r: 0\n");
	}

	return res;
}


int com_put_normal_clk(int fd_out, char * name)
{
	int res;

	switch ( (res = put_on_normal_condition()) ){
	case 1:
		fd_printf(fd_out,"# Is current condition\n");
		fd_printf(fd_out,"r: 2\n");
		break;
	case 0:
		fd_printf(fd_out,"# Now in normal condition\n");
		fd_printf(fd_out,"r: 1\n");
		break;
	default:
		fd_printf(fd_out,"# ERROR: continuing in fail condition\n");
		fd_printf(fd_out,"r: 0\n");
	}

	return res;
}

